@@ -11,7 +11,7 @@ utils::globalVariables(c("a", "a1", "allele","a1_mm", "a2", "a2_mm", "afa_freq",
                          "dpb1_tmp8", "dpb2_mm", "dpb2_tmp2", "dpb2_tmp8", "dqa1_mm", "dqa2_mm", "dqb1", "dqb1_mm",
                          "dqb2", "dqb2_mm", "drb", "drb1", "drb1_mm", "drb2", "drb2_mm", "drb31", "drb32", "drb345", "drb41",
                          "drb42", "drb51", "drb52", "drw1_mm", "drw2_mm", "dup_a", "dup_b", "dup_c", "dup_dqb1", "dup_drb1",
-                         "dup_drb345",
+                         "dup_drb345", "mm_cnt_uniq", "haplotype_id",
                          "eplet", "ethnicity",
                          "freq", "fst_a", "fst_b", "fst_c", "fst_dqb1", "fst_drb1", "fst_drb345",
                          "gene", "his_freq",
